import {
  select,
  max,
  csv,
  scaleBand,
  scaleLinear,
  axisLeft,
  axisBottom,
} from 'd3';

const MusicBrainzApi = require('musicbrainz-api').MusicBrainzApi;
const mbApi = new MusicBrainzApi({
  appName: 'projet-ux',
  appVersion: '0.1.0',
  appContactInfo: 'johan.rieupatey@toulouse-miage.fr'
});
const artist = async mbApi.lookupEntity('artist', 'ab2528d9-719f-4261-8098-21849222a0f2');

// Dimensions du graphe 
var margin = {top: 20, right: 20, bottom: 50, left: 70},
    width = 960 - margin.left - margin.right,
    height = 500 - margin.top - margin.bottom;

var parseTime = d3.timeParse("%d-%b-%y");

// Range
var x = d3.scaleTime().range([0, width]);
var y = d3.scaleLinear().range([height, 0]);

// Ligne
var valueline = d3.line()
    .x(function(d) { return x(d.date); })
    .y(function(d) { return y(d.close); });

// SVG
var svg = d3.select("body").append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
  .append("g")
    .attr("transform",
          "translate(" + margin.left + "," + margin.top + ")");

// Récupération des données
d3.xml("data.csv").then(function(data) {

  // Formattage
  data.forEach(function(d) {
      d.date = parseTime(d.date);
      d.close = +d.close;
  });

  // Mise à l'échelle des données
  x.domain(d3.extent(data, function(d) { return d.date; }));
  y.domain([0, d3.max(data, function(d) { return d.close; })]);

  // Valeur de la ligne
  svg.append("path")
      .data([data])
      .attr("class", "line")
      .attr("d", valueline);

  // Axe X
  svg.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x));

  // Axe Y
  svg.append("g")
      .call(d3.axisLeft(y))